==> mschuchard-extended_stdlib-0.9.2.tar.gz: mschuchard-extended_stdlib-0.9.2/tasks/csr_attributes.rb <==
#!/opt/puppetlabs/puppet/bin/ruby
require 'json'
require 'yaml'
require 'puppet'
require 'facter'

# establish conf
CONF = Facter.value(:kernel) == 'windows' ? 'C:\ProgramData\PuppetLabs\puppet\etc\csr_attributes.yaml' : '/etc/puppetlabs/puppet/csr_attributes.yaml'
# read in params and shallow symbolize keys
PARAMS = JSON.parse($stdin.read).transform_keys(&:to_sym)
# set default values
PARAMS[:extension_requests] ||= {}
PARAMS[:custom_attributes] ||= {}
PARAMS[:purge_extension_requests] ||= false
PARAMS[:purge_custom_attributes] ||= false

def set_csr_attributes(extension_requests = {}, custom_attributes = {}, purge_extension_requests = false, purge_custom_attributes = false)
  # initialize new csr attributes
  new_csr_attrs = {}

  # read in current csr attributes file and shallow symbolize keys
  raise Puppet::Error, _("CSR attributes file at #{CONF} is unreadable.") unless File.readable?(CONF)
  csr_attrs = YAML.safe_load(File.read(CONF)).transform_keys(&:to_sym)

  # append or override extension_requests depending upon purging
  new_csr_attrs[:extension_requests] = purge_extension_requests ? extension_requests : csr_attrs[:extension_requests].merge(extension_requests)

  # append or override custom_attributes depending upon purging
  new_csr_attrs[:custom_attributes] = purge_custom_attributes ? custom_attributes : csr_attrs[:custom_attributes].merge(custom_attributes)

  # write updated csr attributes to yaml file in confdir
  raise Puppet::Error, _("CSR attributes file at #{CONF} is unwritable.") unless File.writable?(CONF)
  File.write(CONF, YAML.dump(new_csr_attrs.transform_keys(&:to_s)))

  # construct return
  { status: 'Successfully modified CSR attributes' }
end

# main code execute
begin
  # invoke primary helper method
  result = set_csr_attributes(PARAMS[:extension_requests], PARAMS[:custom_attributes], PARAMS[:purge_extension_requests], PARAMS[:purge_custom_attributes])
  # send success results to stdout
  puts JSON.pretty_generate(result)
  exit 0
rescue Puppet::Error => err
  # send failure results to stdout
  puts(JSON.pretty_generate({ status: 'failure', error: err.message }))
  exit 1
end

==> mschuchard-extended_stdlib-1.2.1.tar.gz: mschuchard-extended_stdlib-1.2.1/tasks/csr_attributes.rb <==
#!/opt/puppetlabs/puppet/bin/ruby
require 'json'
require 'yaml'
require 'puppet'
require 'facter'

# establish conf
CONF = (Facter.value(:kernel) == 'windows') ? 'C:\ProgramData\PuppetLabs\puppet\etc\csr_attributes.yaml' : '/etc/puppetlabs/puppet/csr_attributes.yaml'
# read in params and shallow symbolize keys
PARAMS = JSON.parse($stdin.read).transform_keys(&:to_sym)
# set default values
PARAMS[:extension_requests] ||= {}
PARAMS[:custom_attributes] ||= {}
PARAMS[:purge_extension_requests] ||= false
PARAMS[:purge_custom_attributes] ||= false

def set_csr_attributes(extension_requests = {}, custom_attributes = {}, purge_extension_requests = false, purge_custom_attributes = false)
  # initialize new csr attributes
  new_csr_attrs = {}

  # read in current csr attributes file and shallow symbolize keys
  raise Puppet::Error, _("CSR attributes file at #{CONF} is unreadable.") unless File.readable?(CONF)
  csr_attrs = YAML.safe_load(File.read(CONF)).transform_keys(&:to_sym)

  # append or override extension_requests depending upon purging
  new_csr_attrs[:extension_requests] = purge_extension_requests ? extension_requests : csr_attrs[:extension_requests].merge(extension_requests)

  # append or override custom_attributes depending upon purging
  new_csr_attrs[:custom_attributes] = purge_custom_attributes ? custom_attributes : csr_attrs[:custom_attributes].merge(custom_attributes)

  # write updated csr attributes to yaml file in confdir
  raise Puppet::Error, _("CSR attributes file at #{CONF} is unwritable.") unless File.writable?(CONF)
  File.write(CONF, YAML.dump(new_csr_attrs.transform_keys(&:to_s)))

  # construct return
  { status: 'Successfully modified CSR attributes' }
end

# main code execute
begin
  # invoke primary helper method
  result = set_csr_attributes(PARAMS[:extension_requests], PARAMS[:custom_attributes], PARAMS[:purge_extension_requests], PARAMS[:purge_custom_attributes])
  # send success results to stdout
  puts JSON.pretty_generate(result)
  exit 0
rescue Puppet::Error => err
  # send failure results to stdout
  puts(JSON.pretty_generate({ status: 'failure', error: err.message }))
  exit 1
end
